==> gimp-1.1.10.tar.bz2: gimp-1.1.10/plug-ins/imagemap/imap_cmd_edit_object.c <==
/*
 * This is a plug-in for the GIMP.
 *
 * Generates clickable image maps.
 *
 * Copyright (C) 1998-1999 Maurits Rijk  lpeek.mrijk@consunet.nl
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include "imap_cmd_edit_object.h"

#include "imap_main.h"

static void edit_object_command_destruct(Command_t *parent);
static void edit_object_command_undo(Command_t *parent);

static CommandClass_t edit_object_command_class = {
   edit_object_command_destruct,
   NULL,			/* edit_object_command_execute */
   edit_object_command_undo,
   edit_object_command_undo
};

typedef struct {
   Command_t parent;
   Object_t *obj;
   Object_t *copy;
} EditObjectCommand_t;

Command_t* 
edit_object_command_new(Object_t *obj)
{
   EditObjectCommand_t *command = g_new(EditObjectCommand_t, 1);
   command->obj = object_ref(obj);
   command->copy = object_clone(obj);
   return command_init(&command->parent, "Edit Object", 
		       &edit_object_command_class);
}

static void
edit_object_command_destruct(Command_t *parent)
{
   EditObjectCommand_t *command = (EditObjectCommand_t*) parent;
   object_unref(command->copy);
   object_unref(command->obj);
}

static void
edit_object_command_undo(Command_t *parent)
{
   EditObjectCommand_t *command = (EditObjectCommand_t*) parent;
   Object_t *copy = object_clone(command->obj);

   object_assign(command->copy, command->obj);
   object_assign(copy, command->copy);

   redraw_preview();		/* Fix me! */
}

==> gimp-1.1.20.tar.bz2: gimp-1.1.20/plug-ins/imagemap/imap_cmd_edit_object.c <==
/*
 * This is a plug-in for the GIMP.
 *
 * Generates clickable image maps.
 *
 * Copyright (C) 1998-1999 Maurits Rijk  lpeek.mrijk@consunet.nl
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include "imap_cmd_edit_object.h"
#include "libgimp/stdplugins-intl.h"
#include "imap_main.h"

static void edit_object_command_destruct(Command_t *parent);
static void edit_object_command_undo(Command_t *parent);

static CommandClass_t edit_object_command_class = {
   edit_object_command_destruct,
   NULL,			/* edit_object_command_execute */
   edit_object_command_undo,
   edit_object_command_undo
};

typedef struct {
   Command_t parent;
   Object_t *obj;
   Object_t *copy;
} EditObjectCommand_t;

Command_t* 
edit_object_command_new(Object_t *obj)
{
   EditObjectCommand_t *command = g_new(EditObjectCommand_t, 1);
   command->obj = object_ref(obj);
   command->copy = object_clone(obj);
   return command_init(&command->parent, _("Edit Object"), 
		       &edit_object_command_class);
}

static void
edit_object_command_destruct(Command_t *parent)
{
   EditObjectCommand_t *command = (EditObjectCommand_t*) parent;
   object_unref(command->copy);
   object_unref(command->obj);
}

static void
edit_object_command_undo(Command_t *parent)
{
   EditObjectCommand_t *command = (EditObjectCommand_t*) parent;
   Object_t *copy = object_clone(command->obj);

   object_assign(command->copy, command->obj);
   object_assign(copy, command->copy);

   redraw_preview();		/* Fix me! */
}
